/* This file is automatically generated by configure.  Do not modify by hand. */
/* Define if compiling with the snmpv3/usmConf module files.  */
#define USING_SNMPV3_USMCONF_MODULE 1
 
/* Define if compiling with the agentx/master module files.  */
#define USING_AGENTX_MASTER_MODULE 1
 
/* Define if compiling with the agentx/subagent module files.  */
#define USING_AGENTX_SUBAGENT_MODULE 1
 
/* Define if compiling with the utilities/execute module files.  */
#define USING_UTILITIES_EXECUTE_MODULE 1
 
/* Define if compiling with the utilities/iquery module files.  */
#define USING_UTILITIES_IQUERY_MODULE 1
 
/* Define if compiling with the mibII/vacm_conf module files.  */
#define USING_MIBII_VACM_CONF_MODULE 1
 
/* Define if compiling with the agentx/protocol module files.  */
#define USING_AGENTX_PROTOCOL_MODULE 1
 
/* Define if compiling with the agentx/client module files.  */
#define USING_AGENTX_CLIENT_MODULE 1
 
/* Define if compiling with the agentx/master_admin module files.  */
#define USING_AGENTX_MASTER_ADMIN_MODULE 1
 
/* Define if compiling with the agentx/agentx_config module files.  */
#define USING_AGENTX_AGENTX_CONFIG_MODULE 1
 
